- 0.2.4 - Fixes for get and put, add ls
- 0.2.3 - Add some minor methods and refactor
- 0.2.2 - Add documentation example
- 0.2.1 - Add safe_run, get_shadowset_members
- 0.2.0 - Add PML addon, refactor
- 0.1.3 - Add queue job stop/start
- 0.1.2 - Add lsof wrapper
- 0.1.1 - Add put, get wrappers
- 0.1.0 - Initial version
